@@ -167,11 +167,12 @@ static void yyerror(const string s)
     ; /* don't report any more errors */
 }
 
-#define call(fn, args) (fn ? fn args : NULL)
+/* call -- if the function exists, call it with the given aguments */
+#define call(fn, args) do {if (fn) (fn)args;} while (0)
 
 
 /* Line 189 of yacc.c  */
-#line 175 "html.c"
+#line 176 "html.c"
 
 /* Enabling traces.  */
 #ifndef YYDEBUG
@@ -230,7 +231,7 @@ typedef union YYSTYPE
 {
 
 /* Line 214 of yacc.c  */
-#line 102 "html.y"
+#line 103 "html.y"
 
     string s;
     pairlist p;
@@ -238,7 +239,7 @@ typedef union YYSTYPE
 
 
 /* Line 214 of yacc.c  */
-#line 242 "html.c"
+#line 243 "html.c"
 } YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
@@ -250,7 +251,7 @@ typedef union YYSTYPE
 
 
 /* Line 264 of yacc.c  */
-#line 254 "html.c"
+#line 255 "html.c"
 
 #ifdef short
 # undef short
@@ -541,9 +542,9 @@ static const yytype_int8 yyrhs[] =
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const yytype_uint8 yyrline[] =
 {
-       0,   115,   115,   115,   119,   120,   121,   122,   123,   124,
-     125,   126,   127,   130,   131,   134,   135,   138,   141,   144,
-     149,   152,   153,   157
+       0,   116,   116,   116,   120,   121,   122,   123,   124,   125,
+     126,   127,   128,   131,   132,   135,   136,   139,   142,   145,
+     150,   153,   154,   158
 };
 #endif
 
@@ -1459,77 +1460,77 @@ yyreduce:
         case 2:
 
 /* Line 1455 of yacc.c  */
-#line 115 "html.y"
-    {data = call(h.start, ());}
+#line 116 "html.y"
+    {data = h.start ? h.start() : NULL;}
     break;
 
   case 3:
 
 /* Line 1455 of yacc.c  */
-#line 116 "html.y"
+#line 117 "html.y"
     {call(h.end, (data));}
     break;
 
   case 4:
 
 /* Line 1455 of yacc.c  */
-#line 119 "html.y"
+#line 120 "html.y"
     {call(h.comment, (data, (yyvsp[(2) - (2)].s)));}
     break;
 
   case 5:
 
 /* Line 1455 of yacc.c  */
-#line 120 "html.y"
+#line 121 "html.y"
     {call(h.text, (data, (yyvsp[(2) - (2)].s)));}
     break;
 
   case 9:
 
 /* Line 1455 of yacc.c  */
-#line 124 "html.y"
+#line 125 "html.y"
     {call(h.pi, (data, (yyvsp[(2) - (2)].s)));}
     break;
 
   case 10:
 
 /* Line 1455 of yacc.c  */
-#line 125 "html.y"
+#line 126 "html.y"
     {call(h.endincl, (data));}
     break;
 
   case 13:
 
 /* Line 1455 of yacc.c  */
-#line 130 "html.y"
+#line 131 "html.y"
     {call(h.starttag, (data, (yyvsp[(1) - (3)].s), (yyvsp[(2) - (3)].p)));}
     break;
 
   case 14:
 
 /* Line 1455 of yacc.c  */
-#line 131 "html.y"
+#line 132 "html.y"
     {call(h.emptytag, (data, (yyvsp[(1) - (3)].s), (yyvsp[(2) - (3)].p)));}
     break;
 
   case 15:
 
 /* Line 1455 of yacc.c  */
-#line 134 "html.y"
+#line 135 "html.y"
     {(yyval.p) = (yyvsp[(1) - (2)].p); (yyval.p)->next = (yyvsp[(2) - (2)].p);}
     break;
 
   case 16:
 
 /* Line 1455 of yacc.c  */
-#line 135 "html.y"
+#line 136 "html.y"
     {(yyval.p) = NULL;}
     break;
 
   case 17:
 
 /* Line 1455 of yacc.c  */
-#line 138 "html.y"
+#line 139 "html.y"
     {pairlist h = malloc(sizeof(*h));
 					 assert(h != NULL); h->name = (yyvsp[(1) - (1)].s);
 					 h->value=NULL; (yyval.p) = h;}
@@ -1538,7 +1539,7 @@ yyreduce:
   case 18:
 
 /* Line 1455 of yacc.c  */
-#line 141 "html.y"
+#line 142 "html.y"
     {pairlist h = malloc(sizeof(*h));
 					 assert(h != NULL); h->name = (yyvsp[(1) - (3)].s);
 					 h->value = (yyvsp[(3) - (3)].s); (yyval.p) = h;}
@@ -1547,7 +1548,7 @@ yyreduce:
   case 19:
 
 /* Line 1455 of yacc.c  */
-#line 144 "html.y"
+#line 145 "html.y"
     {pairlist h = malloc(sizeof(*h));
 					 assert(h != NULL); h->name = (yyvsp[(1) - (3)].s);
 					 h->value = (yyvsp[(3) - (3)].s); (yyval.p) = h;}
@@ -1556,21 +1557,21 @@ yyreduce:
   case 20:
 
 /* Line 1455 of yacc.c  */
-#line 149 "html.y"
+#line 150 "html.y"
     {call(h.endtag, (data, (yyvsp[(1) - (2)].s)));}
     break;
 
   case 21:
 
 /* Line 1455 of yacc.c  */
-#line 152 "html.y"
+#line 153 "html.y"
     {call(h.decl, (data, (yyvsp[(2) - (6)].s), (yyvsp[(4) - (6)].s), (yyvsp[(5) - (6)].s)));}
     break;
 
   case 22:
 
 /* Line 1455 of yacc.c  */
-#line 153 "html.y"
+#line 154 "html.y"
     {if (strcasecmp((yyvsp[(3) - (5)].s), "public") == 0)
 				     	   call(h.decl, (data, (yyvsp[(2) - (5)].s), (yyvsp[(4) - (5)].s), NULL));
 					 else /* "system" */
@@ -1580,14 +1581,14 @@ yyreduce:
   case 23:
 
 /* Line 1455 of yacc.c  */
-#line 157 "html.y"
+#line 158 "html.y"
     {call(h.decl, (data, (yyvsp[(2) - (3)].s), NULL, NULL));}
     break;
 
 
 
 /* Line 1455 of yacc.c  */
-#line 1591 "html.c"
+#line 1592 "html.c"
       default: break;
     }
   YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);
