@@ -1,12 +1,12 @@
 /*
  * Add an ID to selected elements
  *
- * Copyright  2000 World Wide Web Consortium
+ * Copyright  2000-2012 World Wide Web Consortium
  * See http://www.w3.org/Consortium/Legal/copyright-software
  *
  * Author: Bert Bos <bert@w3.org>
  * Created: 20 Aug 2000
- * Version: $Id: hxaddid.c,v 1.4 2011/08/26 00:29:07 bbos Exp $
+ * Version: $Id: hxaddid.c,v 1.6 2013-03-23 23:18:09 bbos Exp $
  *
  **/
 #include <config.h>
@@ -15,6 +15,7 @@
 #include <stdlib.h>
 #include <stdio.h>
 #include <time.h>
+#include <stdbool.h>
 #if STDC_HEADERS
 # include <string.h>
 #else
@@ -43,13 +44,13 @@
 #include "class.e"
 
 static Tree tree;
-static Boolean xml = False;			/* Use <empty /> convention */
+static bool xml = false;			/* Use <empty /> convention */
 static string targetelement = NULL;		/* Element to extract */
 static string targetclass = NULL;		/* Class to extract */
 
 
 /* is_match check whether the element matches the target element and class */
-static Boolean is_match(const string name, pairlist attribs)
+static bool is_match(const string name, pairlist attribs)
 {
   if (xml)
     return ((!targetelement || strcasecmp(name, targetelement) == 0)
@@ -168,9 +169,8 @@ static void expand(Tree t)
 /* usage -- print usage message and exit */
 static void usage(string name)
 {
-  errexit("Version %s\n\
-Usage: %s [-x] [--] elem|.class|elem.class [html-file]\n",
-	  VERSION, name);
+  errexit("Usage: %s [-x] [-v] [--] elem|.class|elem.class [html-file]\n",
+	  name);
 }
 
 
@@ -194,7 +194,8 @@ int main(int argc, char *argv[])
   /* Parse command line options */
   for (i = 1; i < argc && argv[i][0] == '-' && !eq(argv[i], "--"); i++) {
     switch (argv[i][1]) {
-      case 'x': xml = True; break;
+      case 'x': xml = true; break;
+      case 'v': printf("Version: %s %s\n", PACKAGE, VERSION); return 0;
       default: usage(argv[0]);
     }
   }
