@@ -58,12 +58,12 @@
  *     mistake occurrences of these two strings inside CDATA sections
  *     or attribute values for comment delimiters.
  *
- * Copyright  1994-2010 World Wide Web Consortium
+ * Copyright  1994-2012 World Wide Web Consortium
  * See http://www.w3.org/Consortium/Legal/copyright-software
  *
  * Author: Bert Bos <bert@w3.org>
  * Created: 18 March 2000
- * Version: $Id: hxcite.c,v 1.4 2010/11/18 12:41:37 bbos Exp $
+ * Version: $Id: hxcite.c,v 1.6 2013-03-23 23:18:09 bbos Exp $
  **/
 
 #include <config.h>
@@ -92,6 +92,7 @@
 #endif
 
 #include <ctype.h>
+#include <stdbool.h>
 #include "export.h"
 #include "heap.e"
 #include "types.e"
@@ -109,11 +110,11 @@ static string prog;				/* = argv[0] */
 static string pattern =
   "<a href=\"%b#%L\" rel=\"biblioentry\">[%L]<!--{{%m%L}}--></a>";
 static FILE *aux;
-static Boolean skip_comments = False; /* Whether to skip [[ inside <!----> */
+static bool skip_comments = false; /* Whether to skip [[ inside <!----> */
 
 
 /* label_exists -- check if the label exists in the bibliographic database */
-static Boolean label_exists(const string label)
+static bool label_exists(const string label)
 {
   ENTRY e = {label, NULL};
 
@@ -122,7 +123,7 @@ static Boolean label_exists(const string label)
 
 
 /* valid_label -- check if the label is well-formed */
-static Boolean valid_label(const string label)
+static bool valid_label(const string label)
 {
   int i;
 
@@ -130,8 +131,8 @@ static Boolean valid_label(const string label)
     if (! isalnum(label[i])
 	&& label[i] != '-'
 	&& label[i] != '_'
-	&& label[i] != '.') return False;
-  return True;
+	&& label[i] != '.') return false;
+  return true;
 }
 
 
@@ -159,7 +160,7 @@ static void expand_ref(const string label)
 
 /* process_line -- look for citations in a line */
 EXPORT void process_line(const string text, const string fname, int lineno,
-			 Boolean *in_comment)
+			 bool *in_comment)
 {
   string h = text, p, q, label;
   char c;
@@ -173,7 +174,7 @@ EXPORT void process_line(const string text, const string fname, int lineno,
 
     if (strncmp(p, "-->", 3) == 0) {		/* End of comment */
       putchar(*(h++));
-      *in_comment = False;
+      *in_comment = false;
       continue;
     }
     if (strncmp(p, "<!--", 4) == 0) {		/* Begin of comment */
@@ -260,9 +261,8 @@ static void parse_db(const string db)
 /* usage -- print usage message and exit */
 static void usage(void)
 {
-  errexit("Version %s\n\
-Usage: %s [-b base] [-p pattern] [-a auxfile] [-c] bib-file [HTML-file]\n",
-	  VERSION, prog);
+  errexit("Usage: %s [-b base] [-p pattern] [-a auxfile] [-c] [-v] bib-file [HTML-file]\n",
+	  prog);
 }
 
 
@@ -270,7 +270,7 @@ int main(int argc, char *argv[])
 {
   char line[LINESIZE];
   string h, auxfile = NULL, dbfile = NULL, infile = NULL;
-  Boolean in_comment = False;
+  bool in_comment = false;
   int i, e, lineno;
   FILE *f;
 
@@ -282,7 +282,8 @@ int main(int argc, char *argv[])
     case 'p': pattern = argv[++i]; break;	/* Form of expanded ref */
     case 'a': auxfile = argv[++i]; break;	/* Name of auxfile */
     case 'm': mark = argv[++i]; marklen = strlen(mark); break; /* After "[[" */
-    case 'c': skip_comments = True; break;	/* Skip [[ in comments */
+    case 'c': skip_comments = true; break;	/* Skip [[ in comments */
+    case 'v': printf("Version: %s %s\n", PACKAGE, VERSION); return 0;
     default: usage();
     }
   }
