@@ -16,7 +16,7 @@
  * Created: 5 Dec 2008
  * Author: Bert Bos <bert@w3.org>
  *
- * Copyright © 2008 W3C
+ * Copyright © 2008-2012 W3C
  * See http://www.w3.org/Consortium/Legal/2002/copyright-software-20021231
  */
 
@@ -26,6 +26,7 @@
 #include <assert.h>
 #include <unistd.h>
 #include <sys/errno.h>
+#include <stdbool.h>
 #if HAVE_STRING_H
 #  include <string.h>
 #endif
@@ -44,9 +45,9 @@
 
 #define same(a, b) ((a) ? ((b) && eq((a), (b))) : !(b))
 
-static Boolean has_errors = False;	/* Enconutered errors during parsing */
+static bool has_errors = false;		/* Enconutered errors during parsing */
 static FILE *out = NULL;		/* Where to write output */
-static Boolean has_base = False;	/* Document has a <BASE> element */
+static bool has_base = false;		/* Document has a <BASE> element */
 static string newbase;			/* Path from OLDURL to NEWURL */
 
 
@@ -97,7 +98,7 @@ static conststring adjust_url(const conststring url)
 
 
 /* attribute_is_url -- check if the attribute is URL-valued */
-static Boolean attribute_is_url(const conststring attrib)
+static bool attribute_is_url(const conststring attrib)
 {
   return strcasecmp(attrib, "href") == 0 ||
     strcasecmp(attrib, "src") == 0 ||
@@ -117,7 +118,7 @@ static Boolean attribute_is_url(const conststring attrib)
 void handle_error(void *clientdata, const string s, int lineno)
 {
   fprintf(stderr, "%d: %s\n", lineno, s);
-  has_errors = True;
+  has_errors = true;
 }
 
 
@@ -186,7 +187,7 @@ void handle_starttag(void *clientdata, string name, pairlist attribs)
   fprintf(out, ">");
 
   /* If this is a <BASE> tag, no further adjustments are needed */
-  if (strcasecmp(name, "base") == 0) has_base = True;
+  if (strcasecmp(name, "base") == 0) has_base = true;
 }
 
 
@@ -209,7 +210,7 @@ void handle_emptytag(void *clientdata, string name, pairlist attribs)
   fprintf(out, " />");
 
   /* If this is a <BASE> tag, no further adjustments are needed */
-  if (strcasecmp(name, "base") == 0) has_base = True;
+  if (strcasecmp(name, "base") == 0) has_base = true;
 }
 
 
@@ -223,7 +224,7 @@ void handle_endtag(void *clientdata, string name)
 /* usage -- print usage message and exit */
 static void usage(const conststring progname)
 {
-  fprintf(stderr, "Usage: %s [-i old-URL] [-o new-URL] [URL [URL]]\n", progname);
+  fprintf(stderr, "Usage: %s [-v] [-i old-URL] [-o new-URL] [URL [URL]]\n", progname);
   exit(1);
 }
 
@@ -246,10 +247,11 @@ int main(int argc, char *argv[])
   set_endtag_handler(handle_endtag);
 
   /* Parse command line */
-  while ((c = getopt(argc, argv, "i:o:")) != -1)
+  while ((c = getopt(argc, argv, "i:o:v")) != -1)
     switch (c) {
     case 'o': newurl = optarg; break;
     case 'i': oldurl = optarg; break;
+    case 'v': printf("Version: %s %s\n", PACKAGE, VERSION); return 0;
     default: usage(argv[0]);
     }
   if (argc > optind + 2) usage(argv[0]);
