@@ -10,7 +10,7 @@
  *
  * Bert Bos
  * Created Nov 1998
- * $Id: hxcount.c,v 1.2 2011/08/26 00:29:07 bbos Exp $
+ * $Id: hxcount.c,v 1.3 2013-03-23 23:18:09 bbos Exp $
  */
 #include <config.h>
 #include <stdio.h>
@@ -31,6 +31,7 @@
 #endif
 #include <stdlib.h>
 #include <assert.h>
+#include <stdbool.h>
 #include "export.h"
 #include "types.e"
 #include "html.e"
@@ -46,7 +47,7 @@ typedef struct _pair {
 
 static pair *freq = NULL;
 static int nrelems = 0;
-static Boolean has_errors = False;
+static bool has_errors = false;
 
 
 /* countstring -- add 1 to number of occurences for s (case-insensitively) */
@@ -86,7 +87,7 @@ static void count(char *name, pairlist attribs)
 void handle_error(void *clientdata, const string s, int lineno)
 {
   fprintf(stderr, "%d: %s\n", lineno, s);
-  has_errors = True;
+  has_errors = true;
 }
 
 /* start -- called before the first event is reported */
