@@ -2,12 +2,12 @@
  * Output all elements with a certain name and/or class.
  * Input must be well-formed, since no HTML heuristics are applied.
  *
- * Copyright  2000 World Wide Web Consortium
+ * Copyright  2000-2012 World Wide Web Consortium
  * See http://www.w3.org/Consortium/Legal/copyright-software
  *
  * Author: Bert Bos <bert@w3.org>
  * Created: 20 Aug 2000
- * Version: $Id: hxextract.c,v 1.3 2011/08/26 00:29:06 bbos Exp $
+ * Version: $Id: hxextract.c,v 1.5 2013-03-23 23:18:09 bbos Exp $
  */
 #include <config.h>
 #include <assert.h>
@@ -15,6 +15,7 @@
 #include <stdlib.h>
 #include <stdio.h>
 #include <time.h>
+#include <stdbool.h>
 #if STDC_HEADERS
 # include <string.h>
 #else
@@ -39,7 +40,7 @@
 
 #define MAXLINELEN 1024				/* In configfile */
 
-static Boolean xml = False;			/* Use <empty /> convention */
+static bool xml = false;			/* Use <empty /> convention */
 static int copying = 0;				/* Start by not copying */
 static string base = NULL;			/* URL of each file */
 static string endtext = "";			/* Text to insert at end */
@@ -85,7 +86,7 @@ static void handle_decl(void *unused, const string gi,
 static void handle_pi(void *unused, const string pi_text) {}
 
 /* print_tag -- print a start- or empty tag */
-static void print_tag(const string name, pairlist attribs, Boolean empty)
+static void print_tag(const string name, pairlist attribs, bool empty)
 {
   pairlist a;
   conststring t, h;
@@ -106,7 +107,7 @@ static void print_tag(const string name, pairlist attribs, Boolean empty)
 }
 
 /* is_match check whether the element matches the target element and class */
-static Boolean is_match(const string name, pairlist attribs)
+static bool is_match(const string name, pairlist attribs)
 {
   return ((!targetelement || strcasecmp(name, targetelement) == 0)
 	  && (!targetclass || has_class(attribs, targetclass)));
@@ -120,7 +121,7 @@ static void handle_starttag(void *unused, const string name, pairlist attribs)
   if (copying || is_match(name, attribs)) {
     if (!copying && (id = pairlist_get(attribs, "id")))
       add_href(&attribs, base, id);
-    if (!eq(name, "a") && !eq(name, "A")) print_tag(name, attribs, False);
+    if (!eq(name, "a") && !eq(name, "A")) print_tag(name, attribs, false);
     copying++;
   }
 }
@@ -133,7 +134,7 @@ static void handle_emptytag(void *unused, const string name, pairlist attribs)
   if (copying || is_match(name, attribs)) {
     if (!copying && (id = pairlist_get(attribs, "id")))
       add_href(&attribs, base, id);
-    if (!eq(name, "a") && !eq(name, "A")) print_tag(name, attribs, True);
+    if (!eq(name, "a") && !eq(name, "A")) print_tag(name, attribs, true);
   }
 }
 
@@ -172,9 +173,8 @@ static void process_configfile(const string configfile)
 /* usage -- print usage message and exit */
 static void usage(const string name)
 {
-  fprintf(stderr, "Version %s\n\
-Usage: %s [-x] [-s text] [-e text] [-b base] element-or-class [-c configfile | file-or-URL]...\n",
-	  VERSION, name);
+  fprintf(stderr, "Usage: %s [-v] [-x] [-s text] [-e text] [-b base] element-or-class [-c configfile | file-or-URL]...\n",
+	  name);
   exit(1);
 }
 
@@ -200,7 +200,7 @@ int main(int argc, char *argv[])
     if (eq(argv[i], "-h") || eq(argv[i], "-?")) { /* Usage */
       usage(argv[0]);
     } else if (eq(argv[i], "-x")) {		/* XML format */
-      xml = True;
+      xml = true;
     } else if (eq(argv[i], "-s")) {		/* Insert text at start */
       printf("%s", argv[++i]);
     } else if (eq(argv[i], "-e")) {		/* Insert text at end */
@@ -209,6 +209,9 @@ int main(int argc, char *argv[])
       base = argv[++i];
     } else if (eq(argv[i], "-c")) {		/* Config file */
       process_configfile(argv[++i]);
+    } else if (eq(argv[i], "-v")) {
+      printf("Version: %s %s\n", PACKAGE, VERSION);
+      return 0;
     } else if (eq(argv[i], "-")) {		/* "-" = stdin */
       if (!base) base = "";
       yyin = stdin;
