@@ -32,12 +32,15 @@
  * a normal one. "index-inst" is an alias for "index", provided for
  * backward compatibility.
  *
+ * To do: get rid of MAXSTR.
+ * To do: an option to split the index at each new first letter.
+ *
  * Copyright © 1994-2005 World Wide Web Consortium
  * See http://www.w3.org/Consortium/Legal/copyright-software
  *
  * Author: Bert Bos <bert@w3.org>
  * Created: 11 Apr 2000
- * Version: $Id: hxindex.c,v 1.15 2012/03/08 22:22:20 bbos Exp $
+ * Version: $Id: hxindex.c,v 1.18 2013-03-23 23:18:09 bbos Exp $
  *
  **/
 #include <config.h>
@@ -49,6 +52,8 @@
 #include <stdio.h>
 #include <iconv.h>
 #include <unistd.h>
+#include <err.h>
+#include <stdbool.h>
 #if STDC_HEADERS
 # include <string.h>
 #else
@@ -86,7 +91,6 @@ int strerror_r(int errnum, char *buf, size_t n);
 #include "dict.e"
 #include "openurl.e"
 #include "genid.e"
-#include "errexit.e"
 #include "class.e"
 
 #undef USE_DATA_ATTRIBUTE	/* Data attributes are a proposal in HTML5 */
@@ -107,23 +111,26 @@ typedef struct _indexterm {
   string url;
   int importance;		/* 1 (low) or 2 (high) */
   string secno;
+  string doctitle;
   string *terms;		/* Array of subterms */
   wchar_t **sortkeys;		/* Array of normalized subterms */
   int nrkeys;			/* Length of term and sortkeys arrays */
 } *Indexterm;
 
 static Tree tree;
-static Boolean xml = False;	/* Use <empty /> convention */
+static bool xml = false;	/* Use <empty /> convention */
 static string base = NULL;	/* (Rel.) URL of output file */
 static string indexdb = NULL;	/* Persistent store of terms */
 static string* userclassnames = NULL;	/* Persistent store of class names */
 static FILE *globalfile;	/* Must be global for twalk */
 static Indexterm globalprevious; /* Must be global for twalk */
 static string globalurlprevious;/* Must be global for twalk */
-static Boolean bctarget = True;	/* Add <A name=> after IDs */
-static Boolean use_secno = False; /* Anchor text is "#" instead of section # */
-static Boolean final = False;	/* Leave used attributes in document */
-static Boolean trim_punct = True; /* Remove trailing punctuation from terms */
+static bool bctarget = true;	/* Add <A name=> after IDs */
+static bool use_secno = false;	/* Anchor text is "#" instead of section # */
+static bool final = false;	/* Leave used attributes in document */
+static bool trim_punct = true;	/* Remove trailing punctuation from terms */
+static string section_name = NULL; /* Term meaning "section %s" */
+static string unknown_name = NULL; /* Term meaning "without number" */
 
 
 /* handle_error -- called when a parse error occurred */
@@ -328,6 +335,64 @@ static void indent(int n)
   for (; n > 0; n--) printf("  ");
 }
 
+/* print_escaped -- print s escaped for use in an attribute */
+static void print_escaped(const conststring s)
+{
+  conststring h;
+
+  for (h = s; *h; h++) if (*h == '"') printf("&quot;"); else putchar(*h);
+}
+
+/* print_title -- print a TITLE attribute */
+static void print_title(const Indexterm term)
+{
+  enum {TEXT, TAG, DQUOTE, SQUOTE} state;
+  string h;
+
+  assert(use_secno);
+  fputs(" title=\"", stdout);
+  if (base[0]) {		/* Only add document titles if needed */
+    for (state = TEXT, h = term->doctitle; *h; h++) {
+      switch (state) {
+      case TEXT:
+	if (*h == '<') state = TAG;
+	else if (*h == '"') fputs("&quot;", stdout);
+	else putchar(*h);
+	break;
+      case TAG:
+	if (*h == '>') state = TEXT;
+	else if (*h == '"') state = DQUOTE;
+	else if (*h == '\'') state = SQUOTE;
+	break;
+      case DQUOTE:
+	if (*h == '"') state = TAG;
+	break;
+      case SQUOTE:
+	if (*h == '\'') state = TAG;
+	break;
+      default:
+	assert(!"Cannot happen!");
+      }
+    }
+    fputs(", ", stdout);
+  }
+  for (h = section_name; *h; h++)
+    switch (*h) {
+    case '"': fputs("&quot;", stdout); break;
+    case '>': fputs("&gt;", stdout); break;
+    case '<': fputs("&lt;", stdout); break;
+    case '%':
+      if (*(h+1) == '%') {putchar('%'); h++;}
+      else if (*(h+1) != 's') putchar('%');
+      else if (term->secno) {print_escaped(term->secno); h++;}
+      else {print_escaped(unknown_name); h++;}
+      break;
+    default: putchar(*h);
+    }
+  putchar('"');
+}
+
+#if 0
 /* print_full_term -- print the full term for use in a TITLE attribute */
 static void print_full_term(const Indexterm term)
 {
@@ -360,6 +425,7 @@ static void print_full_term(const Indexterm term)
       }
   }
 }
+#endif
 
 /* write_index_item -- write one item in the list of index terms */
 static void write_index_item(const void *term1, const VISIT which,
@@ -398,6 +464,7 @@ static void write_index_item(const void *term1, const VISIT which,
     }
   }
 
+#if 0
   int listmode = 0;
 
   if (folding_cmp(globalprevious->sortkeys, globalprevious->nrkeys,
@@ -409,18 +476,45 @@ static void write_index_item(const void *term1, const VISIT which,
       else
         listmode = strcmp(globalurlprevious, term->url);
     }
+#endif
 
   /* Print a link */
   switch (term->importance) {
     case 1:
+#if 0
       printf("%s <a href=\"%s\" title=\"", listmode ? ";" : ",", term->url);
       print_full_term(term);
       printf("\">%s</a>", use_secno ? term->secno : "#");
+#else
+      printf(", ");
+      printf("<a href=\"");
+      print_escaped(term->url);
+      printf("\"");
+      if (use_secno) print_title(term);
+      printf(">");
+      if (!use_secno) putchar('#');
+      else if (term->secno) print_escaped(term->secno);
+      else  print_escaped(unknown_name);
+      printf("</a>");
+#endif
       break;
     case 2:
+#if 0
       printf("%s <a href=\"%s\" title=\"", listmode ? ";" : ",", term->url);
       print_full_term(term);
       printf("\"><strong>%s</strong></a>", use_secno ? term->secno : "#");
+#else
+      printf(", ");
+      printf("<a href=\"");
+      print_escaped(term->url);
+      printf("\"");
+      if (use_secno) print_title(term);
+      printf("><strong>");
+      if (!use_secno) putchar('#');
+      else if (term->secno) print_escaped(term->secno);
+      else  print_escaped(unknown_name);
+      printf("</strong></a>");
+#endif
       break;
     default:
       assert(! "Cannot happen\n");
@@ -453,13 +547,13 @@ static void mkindex(Indexterm terms)
 }
 
 /* expand -- write the tree, add <A NAME> if needed and replace <!--index--> */
-static void expand(Tree t, Boolean *write, Indexterm terms)
+static void expand(Tree t, bool *write, Indexterm terms)
 {
   conststring val;
   Tree h;
   pairlist a;
   string s;
-  Boolean do_tag;
+  bool do_tag;
 
   for (h = t->children; h != NULL; h = h->sister) {
     switch (h->tp) {
@@ -473,9 +567,9 @@ static void expand(Tree t, Boolean *write, Indexterm terms)
 	  if (!final) printf("<!--%s-->\n", BEGIN_INDEX);
 	  mkindex(terms);
 	  if (!final) printf("<!--%s-->", END_INDEX);
-	  if (eq(s, BEGIN_INDEX)) *write = False;	/* Skip old index */
+	  if (eq(s, BEGIN_INDEX)) *write = false;	/* Skip old index */
 	} else if (eq(s, END_INDEX)) {
-	  *write = True;
+	  *write = true;
 	} else {
 	  printf("<!--%s-->", h->text);
 	}
@@ -590,7 +684,7 @@ static void copy_contents(Tree t, string *s)
 
 /* copy_to_index -- copy the contents of element h to the index db */
 static void copy_to_index(Tree t, Indexterm *terms, int importance,
-			  conststring secno)
+			  conststring secno, conststring doctitle)
 {
   conststring id, title;
   string h;
@@ -611,13 +705,14 @@ static void copy_to_index(Tree t, Indexterm *terms, int importance,
       n = strcspn(title + i, "|");		/* Find | or \0 */
       new(term);
       term->importance = importance;
-      term->secno = newstring(secno);
+      term->secno = secno ? newstring(secno) : NULL;
+      term->doctitle = newstring(doctitle);
       term->url = NULL;
       strapp(&term->url, base, "#", id, NULL);
       h = newnstring(title + i, n);
       parse_subterms(term, h);
       if (! tsearch(term, (void**)terms, termcmp))
-	errexit("Out of memory while parsing term %s\n", h);
+	errx(1, "Out of memory while parsing term %s\n", h);
       i += n;
       if (title[i]) i++;			/* Skip '|' */
     }
@@ -634,19 +729,20 @@ static void copy_to_index(Tree t, Indexterm *terms, int importance,
     if (h) {					/* Non-empty contents */
       new(term);
       term->importance = importance;
-      term->secno = newstring(secno);
+      term->secno = secno ? newstring(secno) : NULL;
+      term->doctitle = newstring(doctitle);
       term->url = NULL;
       strapp(&term->url, base, "#", id, NULL);
       parse_subterms(term, h);
       if (! tsearch(term, (void**)terms, termcmp))
-	errexit("Out of memory while parsing term %s\n", h);
+	errx(1, "Out of memory while parsing term %s", h);
     }
 
   }
 }
 
 /* collect -- collect index terms, add IDs where needed */
-static void collect(Tree t, Indexterm *terms, string *secno)
+static void collect(Tree t, Indexterm *terms, string *secno, string *doctitle)
 {
   int importance;
   Tree h;
@@ -655,13 +751,17 @@ static void collect(Tree t, Indexterm *terms, string *secno)
     switch (h->tp) {
       case Text: case Comment: case Declaration: case Procins: break;
       case Element:
+	if (eq(h->name, "title")) {
+	  dispose(*doctitle);
+	  copy_contents(h, doctitle);
+	}
 	if (has_class(h->attribs, SECNO)) {
 	  dispose(*secno);
 	  copy_contents(h, secno);
 	  trim(*secno);
 	} else if (has_class(h->attribs, NO_NUM)) {
 	  dispose(*secno);
-	  *secno = newstring("#");
+	  *secno = newstring(unknown_name);
 	}
 	if (eq(h->name, "dfn")) importance = 2;
 	else if (has_class(h->attribs,INDEX)||has_class(h->attribs,INDEX_INST))
@@ -673,9 +773,9 @@ static void collect(Tree t, Indexterm *terms, string *secno)
 	if (importance != 0) {
 	  /* Give it an ID, if it doesn't have one */
 	  if (! get_attrib(h, "id")) set_attrib(h, "id", gen_id(h));
-	  copy_to_index(h, terms, importance, *secno);
+	  copy_to_index(h, terms, importance, *secno, *doctitle);
 	} else {
-	  collect(h, terms, secno);
+	  collect(h, terms, secno, doctitle);
 	}
 	break;
       case Root: assert(! "Cannot happen"); break;
@@ -688,7 +788,7 @@ static void collect(Tree t, Indexterm *terms, string *secno)
 static void load_index(const string indexdb, Indexterm *terms)
 {
   FILE *f;
-  int n, n3;
+  int n1, n2, n3, n4, n5;
   char line[MAXSTR];
   Indexterm term;
   string h;
@@ -696,24 +796,53 @@ static void load_index(const string indexdb, Indexterm *terms)
   if (! (f = fopen(indexdb, "r"))) return;	/* Assume file not found... */
 
   while (fgets(line, sizeof(line), f)) {
+#if 1
+    n1 = strcspn(line, "\t");
+    if (line[n1] != '\t') errx(1, "Illegal syntax in %s", indexdb);
+    n2 = n1 + 1 + strcspn(line + n1 + 1, "\t");
+    if (line[n2] != '\t') errx(1, "Illegal syntax in %s", indexdb);
+    n3 = n2 + 1 + strcspn(line + n2 + 1, "\t");
+    if (line[n3] != '\t') errx(1, "Illegal syntax in %s", indexdb);
+    n4 = n3 + 1 + strcspn(line + n3 + 1, "\t");
+    if (line[n4] != '\t') errx(1, "Illegal syntax in %s", indexdb);
+    n5 = n4 + 1 + strcspn(line + n4 + 1, "\t\n");
+    if (line[n5] != '\n') errx(1, "Illegal syntax in %s", indexdb);
+    new(term);
+    h = newnstring(line, n1);
+    switch (line[n1 + 1]) {
+      case '1': term->importance = 1; break;
+      case '2': term->importance = 2; break;
+    default: errx(1, "Error in %s (column 2 must be '1' or '2')", indexdb);
+    }
+    term->url = newnstring(line + n2 + 1, n3 - n2 - 1);
+    term->secno = newnstring(line + n3 + 1, n4 - n3 - 1);
+    term->doctitle = newnstring(line + n4 + 1, n5 - n4 - 1);
+    parse_subterms(term, h);
+    if (! tsearch(term, (void**)terms, termcmp))
+      errx(1, "Out of memory while loading %s", indexdb);
+#else
     chomp(line);
     n = strcspn(line, "\t");
-    if (line[n] != '\t') errexit("Illegal syntax in %s\n", indexdb);
+    if (line[n] != '\t') errx(1, "Illegal syntax in %s", indexdb);
     new(term);
     h = newnstring(line, n);
     switch (line[n + 1]) {
       case '1': term->importance = 1; break;
       case '2': term->importance = 2; break;
-      default: errexit("Error in %s (column 2 must be '1' or '2')\n", indexdb);
+    default: errx(1, "Error in %s (column 2 must be '1' or '2')", indexdb);
     }
-    if (line[n+2] != '\t') errexit("Illegal syntax in %s\n", indexdb);
+    if (line[n+2] != '\t') errx(1, "Illegal syntax in %s", indexdb);
     n3 = n + 3 + strcspn(line + n + 3, "\t");
-    if (line[n3] != '\t') errexit("Illegal syntax in %s\n", indexdb);
+    if (line[n3] != '\t') errx(1, "Illegal syntax in %s", indexdb);
+    n4 = n3 + 1 + strcspn(line + n3 + 1, "\t");
+    if (line[n4] != '\t') errx(1, "Illegal syntax in %s", indexdb);
     term->url = newnstring(line + n + 3, n3 - n - 3);
-    term->secno = newstring(line + n3 + 1);
+    term->secno = newnstring(line + n3 + 1, n4 - n3 - 1);
+    term->doctitle = newstring(line + n4 + 1);
     parse_subterms(term, h);
     if (! tsearch(term, (void**)terms, termcmp))
-      errexit("Out of memory while loading %s\n", indexdb);
+      errx(1, "Out of memory while loading %s", indexdb);
+#endif
   }
 
   fclose(f);
@@ -730,8 +859,9 @@ static void save_a_term(const void *term1, const VISIT which, const int dp)
       if (i > 0) fprintf(globalfile, "!!");
       fprintf(globalfile, "%s", term->terms[i]);
     }
-    fprintf(globalfile, "\t%d\t%s\t%s\n", term->importance, term->url,
-	    term->secno);
+    fprintf(globalfile, "\t%d\t%s\t%s\t%s\n", term->importance, term->url,
+	    term->secno ? term->secno : (use_secno ? unknown_name : "#"),
+	    term->doctitle);
   }
 }
 
@@ -739,7 +869,7 @@ static void save_a_term(const void *term1, const VISIT which, const int dp)
 static void save_index(const string indexdb, Indexterm terms)
 {
   if (! (globalfile = fopen(indexdb, "w")))
-    errexit("%s: %s\n", indexdb, strerror(errno));
+    errx(1, "%s: %s", indexdb, strerror(errno));
   twalk(terms, save_a_term);
   fclose(globalfile);
 }
@@ -747,7 +877,7 @@ static void save_index(const string indexdb, Indexterm terms)
 /* usage -- print usage message and exit */
 static void usage(string name)
 {
-  errexit("Version %s\nUsage: %s [-i indexdb] [-b base] [-x] [-t] [-n] [-c userclass] [html-file]\n",
+  errx(1, "Version %s\nUsage: %s [-i indexdb] [-b base] [-x] [-t] [-n] [-c userclass] [-s template] [-u phrase] [html-file]",
 	  VERSION, name);
 }
 
@@ -771,9 +901,9 @@ static string * tokenize(string s)
 /* main */
 int main(int argc, char *argv[])
 {
-  Boolean write = True;
+  bool write = true;
   Indexterm termtree = NULL;	/* Sorted tree of terms */
-  string secno;
+  string secno, doctitle;
   int c, status = 200;
 
   /* Bind the parser callback routines to our handlers */
@@ -790,16 +920,18 @@ int main(int argc, char *argv[])
 
   yyin = NULL;
 
-  while ((c = getopt(argc, argv, "txbi:cnfr")) != -1)
+  while ((c = getopt(argc, argv, "txb:i:cnfrs:u:")) != -1)
   switch (c) {
-  case 't': bctarget = False; break; /* Don't write <a name> after each ID */
-  case 'x': xml = True; break;	/* Output as XML */
+  case 't': bctarget = false; break; /* Don't write <a name> after each ID */
+  case 'x': xml = true; break;	/* Output as XML */
   case 'b': base = newstring(optarg); break; /* Set base of URL */
   case 'i': indexdb = newstring(optarg); break;	/* Set name of index db */
   case 'c': userclassnames = tokenize(optarg); break; /* Set class names */
-  case 'n': use_secno = True; break; /* Print section numbers instead of "#" */
-  case 'f': final = True; break; /* "Final": remove used attributes */
-  case 'r': trim_punct = False; break; /* Do not remove trailing punctuation */
+  case 'n': use_secno = true; break; /* Print section numbers instead of "#" */
+  case 'f': final = true; break; /* "Final": remove used attributes */
+  case 'r': trim_punct = false; break; /* Do not remove trailing punctuation */
+  case 's': section_name = newstring(optarg); break;
+  case 'u': unknown_name = newstring(optarg); break;
   default: usage(argv[0]);
   }
   if (optind == argc) yyin = stdin;
@@ -808,9 +940,11 @@ int main(int argc, char *argv[])
   else yyin = fopenurl(argv[optind], "r", &status);
 
   if (yyin == NULL) {perror(argv[optind]); exit(1);}
-  if (status != 200) errexit("%s : %s\n", argv[optind], http_strerror(status));
+  if (status != 200) errx(1, "%s : %s", argv[optind], http_strerror(status));
 
   if (!base) base = newstring("");
+  if (!section_name) section_name = newstring("section %s");
+  if (!unknown_name) unknown_name = newstring("??");
 
   /* Apply user's locale */
   setlocale(LC_ALL, "");
@@ -822,8 +956,9 @@ int main(int argc, char *argv[])
   if (yyparse() != 0) exit(3);
 
   /* Scan for index terms, add them to the tree, add IDs where needed */
-  secno = newstring("#");
-  collect(get_root(tree), &termtree, &secno);
+  secno = NULL;
+  doctitle = newstring("");
+  collect(get_root(tree), &termtree, &secno, &doctitle);
 
   /* Write out the document, adding <A NAME> and replacing <!--index--> */
   expand(get_root(tree), &write, termtree);
