@@ -18,7 +18,7 @@
  *
  * Bert Bos <bert@w3.org>
  * Created Sep 1997
- * $Id: hxmultitoc.c,v 1.3 2011/08/26 00:29:06 bbos Exp $
+ * $Id: hxmultitoc.c,v 1.4 2013-03-23 23:18:09 bbos Exp $
  */
 #include <config.h>
 #include <assert.h>
@@ -26,6 +26,7 @@
 #include <stdlib.h>
 #include <stdio.h>
 #include <time.h>
+#include <stdbool.h>
 #if STDC_HEADERS
 # include <string.h>
 #else
@@ -50,14 +51,14 @@
 
 #define MAXLINELEN 1024				/* In configfile */
 
-#define EXPAND True
-#define NO_EXPAND False
-#define KEEP_ANCHORS True
-#define REMOVE_ANCHORS False
+#define EXPAND true
+#define NO_EXPAND false
+#define KEEP_ANCHORS true
+#define REMOVE_ANCHORS false
 
 static int toc_low = 1, toc_high = 6;		/* Which headers to include */
-static Boolean xml = False;			/* Use <empty /> convention */
-static Boolean copying = False;			/* Start by not copying */
+static bool xml = false;			/* Use <empty /> convention */
+static bool copying = false;			/* Start by not copying */
 static int curlevel = 0;			/* Level of previous heading */
 static string base = NULL;			/* URL of each file */
 static string endtext = "";			/* Text to insert at end */
@@ -108,7 +109,7 @@ static void handle_header(int level, pairlist attribs)
   } else {
     printf("<li><a href=\"%s#%s\">", base, id ? id : (string) "");
   }
-  copying = True;
+  copying = true;
 }
 
 /* handle_span -- print a <span> starttag but without class=index */
@@ -187,7 +188,7 @@ static void handle_endtag(void *clientdata, const string name)
 	|| eq(name, "h4") || eq(name, "H4") || eq(name, "h5")
 	|| eq(name, "H5") || eq(name, "h6") || eq(name, "H6")) {
       printf("</a>\n");
-      copying = False;
+      copying = false;
     } else if (eq(name, "a") || eq(name, "A")) {
       /* skip anchors */
     } else {
@@ -257,7 +258,7 @@ int main(int argc, char *argv[])
       toc_high = atoi(argv[++i]);
       if (toc_high > 6) toc_high = 6;
     } else if (eq(argv[i], "-x")) {		/* XML format */
-      xml = True;
+      xml = true;
     } else if (eq(argv[i], "-s")) {		/* Insert text at start */
       printf("%s", argv[++i]);
     } else if (eq(argv[i], "-e")) {		/* Insert text at end */
