@@ -30,6 +30,7 @@
 #endif
 #include <stdlib.h>
 #include <assert.h>
+#include <stdbool.h>
 #include "export.h"
 #include "types.e"
 #include "html.e"
@@ -40,8 +41,8 @@
 
 #define XML "{http://www.w3.org/XML/1998/namespace}"
 
-static Boolean has_error = False;
-static Boolean has_ns = False;	/* True if Namespaces occur anywhere in document */
+static bool has_error = false;
+static bool has_ns = false;	/* true if Namespaces occur anywhere in document */
 
 
 /* --------------- implements interface api.h -------------------------- */
@@ -50,7 +51,7 @@ static Boolean has_ns = False;	/* True if Namespaces occur anywhere in document
 void handle_error(void *clientdata, const string s, int lineno)
 {
   fprintf(stderr, "%d: %s\n", lineno, s);
-  has_error = True;
+  has_error = true;
 }
 
 /* start -- called before the first event is reported */
@@ -141,7 +142,7 @@ static void print_tag(const conststring name)
     printf(" xmlns=\"");
     for (j = 1; j < i - 1; j++) putchar(name[j]);
     putchar('"');
-    has_ns = True;
+    has_ns = true;
   } else if (has_ns) {		/* Document has Namespaces, this element not */
     printf(" xmlns=\"\"");
   }
