@@ -67,12 +67,12 @@
  * Part of HTML-XML-utils, see:
  * http://www.w3.org/Tools/HTML-XML-utils/
  *
- * Copyright  1994-2000 World Wide Web Consortium
+ * Copyright  1994-2012 World Wide Web Consortium
  * See http://www.w3.org/Consortium/Legal/copyright-software
  *
  * Author: Bert Bos
  * Created: 2 Dec 1998
- * Version: $Id: hxpipe.c,v 1.5 2011/08/26 20:41:01 bbos Exp $
+ * Version: $Id: hxpipe.c,v 1.7 2013-03-23 23:18:09 bbos Exp $
  *
  **/
 #include <config.h>
@@ -91,6 +91,7 @@
 #endif
 #include <stdlib.h>
 #include <assert.h>
+#include <stdbool.h>
 #include "export.h"
 #include "types.e"
 #include "html.e"
@@ -101,9 +102,9 @@
 
 #define XMLID "{http://www.w3.org/XML/1998/namespace}id"
 
-static Boolean has_error = False;
-static Boolean in_text = False;
-static Boolean linenumbering = False;
+static bool has_error = false;
+static bool in_text = false;
+static bool linenumbering = false;
 
 
 /* escape -- print a string with certain characters escaped */
@@ -129,7 +130,7 @@ static void escape(const string t)
 void handle_error(void *clientdata, const string s, int lineno)
 {
   fprintf(stderr, "%d: %s\n", lineno, s);
-  has_error = True;
+  has_error = true;
 }
 
 /* start -- called before the first event is reported */
@@ -141,13 +142,13 @@ void* start(void)
 /* end -- called after the last event is reported */
 void end(void *clientdata)
 {
-  if (in_text) {putchar('\n'); in_text = False;}
+  if (in_text) {putchar('\n'); in_text = false;}
 }
 
 /* handle_comment -- called after a comment is parsed */
 void handle_comment(void *clientdata, string commenttext)
 {
-  if (in_text) {putchar('\n'); in_text = False;}
+  if (in_text) {putchar('\n'); in_text = false;}
   if (linenumbering) printf("L%d\n", lineno);
   putchar('*');
   escape(commenttext);
@@ -164,7 +165,7 @@ void handle_text(void *clientdata, string text)
   if (! in_text) {
     if (linenumbering) printf("L%d\n", lineno);
     putchar('-');
-    in_text = True;
+    in_text = true;
   }
   escape(text);
 }
@@ -173,7 +174,7 @@ void handle_text(void *clientdata, string text)
 void handle_decl(void *clientdata, string gi, string fpi,
 		 string url)
 {
-  if (in_text) {putchar('\n'); in_text = False;}
+  if (in_text) {putchar('\n'); in_text = false;}
   if (linenumbering) printf("L%d\n", lineno);
   printf("!%s \"%s\" %s\n", gi, fpi ? fpi : "", url ? url : "");
 }
@@ -181,7 +182,7 @@ void handle_decl(void *clientdata, string gi, string fpi,
 /* handle_pi -- called after a PI is parsed */
 void handle_pi(void *clientdata, string pi_text)
 {
-  if (in_text) {putchar('\n'); in_text = False;}
+  if (in_text) {putchar('\n'); in_text = false;}
   if (linenumbering) printf("L%d\n", lineno);
   putchar('?');
   escape(pi_text);
@@ -207,7 +208,7 @@ void print_attrs(const pairlist attribs)
 /* handle_starttag -- called after a start tag is parsed */
 void handle_starttag(void *clientdata, string name, pairlist attribs)
 {
-  if (in_text) {putchar('\n'); in_text = False;}
+  if (in_text) {putchar('\n'); in_text = false;}
   print_attrs(attribs);
   if (linenumbering) printf("L%d\n", lineno);
   putchar('(');
@@ -218,7 +219,7 @@ void handle_starttag(void *clientdata, string name, pairlist attribs)
 /* handle_emptytag -- called after an empty tag is parsed */
 void handle_emptytag(void *clientdata, string name, pairlist attribs)
 {
-  if (in_text) {putchar('\n'); in_text = False;}
+  if (in_text) {putchar('\n'); in_text = false;}
   print_attrs(attribs);
   if (linenumbering) printf("L%d\n", lineno);
   putchar('|');
@@ -229,7 +230,7 @@ void handle_emptytag(void *clientdata, string name, pairlist attribs)
 /* handle_endtag -- called after an endtag is parsed (name may be "") */
 void handle_endtag(void *clientdata, string name)
 {
-  if (in_text) {putchar('\n'); in_text = False;}
+  if (in_text) {putchar('\n'); in_text = false;}
   if (linenumbering) printf("L%d\n", lineno);
   putchar(')');
   printf("%s", name);
@@ -241,13 +242,13 @@ void handle_endtag(void *clientdata, string name)
 /* usage -- print usage message and exit */
 static void usage(string prog)
 {
-  fprintf(stderr, "Version %s\nUsage: %s [-l] [html-file-or-url]\n", VERSION, prog);
+  fprintf(stderr, "Usage: %s [-l] [-v] [html-file-or-url]\n", prog);
   exit(2);
 }
 
 int main(int argc, char *argv[])
 {
-  int i, status = 200;
+  int c, status = 200;
 
   /* Bind the parser callback routines to our handlers */
   set_error_handler(handle_error);
@@ -262,21 +263,21 @@ int main(int argc, char *argv[])
   set_endtag_handler(handle_endtag);
 
   /* Parse command line arguments */
-  for (i = 1; i < argc && argv[i][0] == '-' && !eq(argv[i], "--"); i++) {
-    switch (argv[i][1]) {
-      case 'l': linenumbering = True;; break;
-      default: usage(argv[0]);
+  while ((c = getopt(argc, argv, "lv")) != -1)
+    switch (c) {
+    case 'l': linenumbering = true; break;
+    case 'v': printf("Version: %s %s\n", PACKAGE, VERSION); return 0;
+    case '?': usage(argv[0]); break;
+    default: assert(!"Cannot happen");
     }
-  }
-  if (i < argc && eq(argv[i], "--")) i++;
 
-  if (i == argc) yyin = stdin;
-  else if (i == argc - 1 && eq(argv[i], "-")) yyin = stdin;
-  else if (i == argc - 1) yyin = fopenurl(argv[i], "r", &status);
+  if (optind == argc) yyin = stdin;
+  else if (optind == argc - 1 && eq(argv[optind], "-")) yyin = stdin;
+  else if (optind == argc - 1) yyin = fopenurl(argv[optind], "r", &status);
   else usage(argv[0]);
 
-  if (yyin == NULL) {perror(argv[i]); exit(1);}
-  if (status != 200) errexit("%s : %s\n", argv[i], http_strerror(status));
+  if (yyin == NULL) {perror(argv[optind]); exit(1);}
+  if (status != 200) errexit("%s : %s\n", argv[optind], http_strerror(status));
 
   if (yyparse() != 0) exit(3);
 
