@@ -6,7 +6,7 @@
  *
  * Bert Bos <bert@w3.org>
  * Created Feb 2000
- * $Id: hxprune.c,v 1.5 2011/08/26 20:41:01 bbos Exp $
+ * $Id: hxprune.c,v 1.6 2013-03-23 23:18:09 bbos Exp $
  *
  **/
 /* #include <mcheck.h> */
@@ -16,6 +16,7 @@
 #include <stdlib.h>
 #include <stdio.h>
 #include <time.h>
+#include <stdbool.h>
 #if STDC_HEADERS
 # include <string.h>
 #else
@@ -40,7 +41,7 @@
 #define EXCLUDE_CLASS "exclude"			/* Default value for class */
 
 static Tree tree;
-static Boolean xml = False;			/* Use <empty /> convention */
+static bool xml = false;			/* Use <empty /> convention */
 
 
 /* handle_error -- called when a parse error occurred */
@@ -188,7 +189,7 @@ int main(int argc, char *argv[])
       if (i >= argc - 1) usage(argv[0]);
       class = argv[++i];
     } else if (eq(argv[i], "-x")) {
-      xml = True;
+      xml = true;
     } else {
       yyin = fopenurl(argv[i], "r", &status);
       if (yyin == NULL) {perror(argv[1]); exit(2);}
