@@ -17,12 +17,12 @@
  * program on each of the files. It may be necessary to run the
  * program twice on a series of files, to create all the references.
  *
- * Copyright  2000 World Wide Web Consortium
+ * Copyright  2000-2012 World Wide Web Consortium
  * See http://www.w3.org/Consortium/Legal/copyright-software
  *
  * Author: Bert Bos <bert@w3.org>
  * Created: 4 August 2000
- * Version: $Id: hxref.c,v 1.8 2012/03/08 22:20:37 bbos Exp $
+ * Version: $Id: hxref.c,v 1.12 2013-03-23 23:18:09 bbos Exp $
  **/
 
 #include <config.h>
@@ -30,6 +30,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <ctype.h>
+#include <stdbool.h>
 
 #ifdef HAVE_ERRNO_H
 #  include <errno.h>
@@ -69,8 +70,9 @@
 
 static Tree tree;
 static string base = NULL, progname;
-static Boolean do_xml = False;
-static Boolean use_language = False;
+static bool do_xml = false;
+static bool use_language = false;
+static char *extras = "-_@()";			/* Significant characters */
 
 
 /* handle_error -- called when a parse error occurred */
@@ -198,7 +200,8 @@ static string normalize(string s)
 
   for (; s[j]; j++)
     if (isupper(s[j])) s[i++] = tolower(s[j]);	/* Upper -> lowercase */
-    else if (isalnum(s[j]) || s[j] == '-') s[i++] = s[j]; /* Keep these */
+    else if (isalnum(s[j])) s[i++] = s[j];	/* Keep these */
+    else if (strchr(extras, s[j])) s[i++] = s[j]; /* Keep these, too */
     else if (! isspace(s[j])) ;			/* Skip rest, except spaces */
     else if (s[i-1] != ' ') s[i++] = ' ';	/* Collapse whitespace */
 
@@ -371,7 +374,7 @@ static void find_instances(Tree tree, const conststring language)
 
 
 /* write_doc -- write the tree to a file */
-static void write_doc(Tree n, Boolean do_xml, FILE *f)
+static void write_doc(Tree n, bool do_xml, FILE *f)
 {
   pairlist h;
   Tree l;
@@ -421,8 +424,8 @@ static void write_doc(Tree n, Boolean do_xml, FILE *f)
 static void usage(void)
 {
   fprintf(stderr,
-	  "Version %s\nUsage: %s [-b base] [-i index] [-x] [-l] [--] [input [output]]\n",
-	  VERSION, progname);
+	  "Usage: %s [-v] [-b base] [-i index] [-x] [-l] [--] [input [output]]\n",
+	  progname);
   exit(1);
 }
 
@@ -457,7 +460,7 @@ int main(int argc, char *argv[])
 	break;
       case 'x':
 	if (do_xml) usage();			/* Option was already set */
-	do_xml = True;
+	do_xml = true;
 	break;
       case 'i':
 	if (!argv[i][2] && i + 1 == argc) usage(); /* Missing argument */
@@ -467,8 +470,11 @@ int main(int argc, char *argv[])
 	break;
       case 'l':
 	if (use_language) usage(); 		/* Option was already set */
-	use_language = True;
+	use_language = true;
 	break;
+      case 'v':
+	printf("Version: %s %s\n", PACKAGE, VERSION);
+	return 0;
       case '\0':
 	if (!yyin) yyin = stdin;
 	else if (!outfile) outfile = stdout;
