@@ -11,7 +11,7 @@
  *
  * Author: Bert Bos
  * Created: 8 November 2005
- * Version: $Id: hxunxmlns.c,v 1.4 2011/08/26 20:41:01 bbos Exp $
+ * Version: $Id: hxunxmlns.c,v 1.5 2013-03-23 23:18:10 bbos Exp $
  *
  **/
 #include <config.h>
@@ -30,6 +30,7 @@
 #endif
 #include <stdlib.h>
 #include <assert.h>
+#include <stdbool.h>
 #include "export.h"
 #include "types.e"
 #include "html.e"
@@ -44,7 +45,7 @@ const static size_t XMLNSLEN = 39;		/* strlen(XMLNS) */
 
 extern int yylineno;				/* From scan.l */
 
-static Boolean has_error = False;
+static bool has_error = false;
 
 
 /* --------------- implements interface api.h -------------------------- */
@@ -53,7 +54,7 @@ static Boolean has_error = False;
 void handle_error(void *clientdata, const string s, int lineno)
 {
   fprintf(stderr, "%d: %s\n", lineno, s);
-  has_error = True;
+  has_error = true;
 }
 
 /* start -- called before the first event is reported */
@@ -113,7 +114,7 @@ static void print_attrs(const pairlist attribs)
     } else if (! (h = strchr(p->name, '}'))) {
       fprintf(stderr, "%d: Unmatched \"{\" in attribute name (\"%s\")\n",
 	      yylineno, p->name);
-      has_error = True;
+      has_error = true;
     } else {
       printf(" xmlns:x%d=\"", n);
       for (s = p->name + 1; s != h; s++) putchar(*s);
@@ -136,7 +137,7 @@ static void print_tag_start(const string name)
   } else if (! (h = strchr(name, '}'))) {
     fprintf(stderr, "%d: Unmatched \"{\" in tag name (\"%s\")\n",
 	    yylineno, name);
-    has_error = True;
+    has_error = true;
   } else {
     printf("<%s xmlns=\"", h + 1);
     for (s = name + 1; s != h; s++) putchar(*s);
@@ -170,7 +171,7 @@ void handle_endtag(void *clientdata, string name)
   } else if (! (h = strchr(name, '}'))) {
     fprintf(stderr, "%d: Unmatched \"{\" in tag name (\"%s\")\n",
 	    yylineno, name);
-    has_error = True;
+    has_error = true;
   } else {
     printf("</%s>", h + 1);
   }
