@@ -6,13 +6,14 @@
  *
  * Bert Bos <bert@w3.org>
  * Created 31 July 1999
- * $Id: hxwls.c,v 1.4 2011/08/26 20:41:01 bbos Exp $
+ * $Id: hxwls.c,v 1.5 2013-03-23 23:18:10 bbos Exp $
  */
 #include <config.h>
 #include <assert.h>
 #include <ctype.h>
 #include <stdlib.h>
 #include <stdio.h>
+#include <stdbool.h>
 #if STDC_HEADERS
 # include <string.h>
 #else
@@ -34,11 +35,11 @@
 #include "url.e"
 #include "errexit.e"
 
-static Boolean has_error = False;
+static bool has_error = false;
 static string base = NULL;
 static string self;
 static enum {Short, Long, HTML, Tuple} format = Short;	/* Option -l -h -t */
-static Boolean relative = False;		/* Option -r */
+static bool relative = false;		/* Option -r */
 
 
 /* output -- print the link (lowercases rel argument) */
@@ -83,7 +84,7 @@ static void output(const conststring type, const conststring rel,
 void handle_error(void *clientdata, const string s, int lineno)
 {
   fprintf(stderr, "%d: %s\n", lineno, s);
-  has_error = True;
+  has_error = true;
 }
 
 /* start -- called before the first event is reported */
@@ -235,7 +236,7 @@ int main(int argc, char *argv[])
     switch (argv[i][1]) {
       case 'l': format = Long; break;		/* Long listing */
       case 'b': base = strdup(argv[++i]); break; /* Set base of URL */
-      case 'r': relative = True; break;		/* Do not make URLs absolute */
+      case 'r': relative = true; break;		/* Do not make URLs absolute */
       case 'h': format = HTML; break;		/* Output in HTML format */
       case 't': format = Tuple; break;		/* Output as 4-tuples */
       default: usage(argv[0]);
