@@ -343,6 +343,7 @@ EXPORT FILE *fopenurl3(const conststring method, const conststring url,
   *status = 200;
 
   /* In case the url isn't a full URL, assume it is a local file */
+  assert(url != NULL);
   n = strspn(url,
     "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789+-.");
   if (url[n] != ':') return fopen(url, mode);
@@ -447,6 +448,7 @@ EXPORT FILE *fopenurl2(const conststring url, const conststring mode,
 		       const Dictionary request, Dictionary response,
 		       int maxredirs, int *status)
 {
+  assert(url != NULL);
   return fopenurl3("GET", url, mode, request, response, maxredirs, status);
 }
 
@@ -455,6 +457,7 @@ EXPORT FILE *fopenurl2(const conststring url, const conststring mode,
 EXPORT FILE *fopenurl(const conststring path, const conststring mode,
 		      int *status)
 {
+  assert(path != NULL);
   debug("+ fopenurl(\"%s\", \"%s\")\n", path, mode);
   return fopenurl2(path, mode, NULL, NULL, MAXREDIRECTS, status);
 }
