@@ -13,7 +13,7 @@
  *
  * Author: Bert Bos <bert@w3.org>
  * Created: 8 July 2001
- * Version: $Id: selector.c,v 1.7 2005/12/16 01:21:09 bbos Exp $
+ * Version: $Id: selector.c,v 1.9 2013-03-23 23:18:10 bbos Exp $
  **/
 
 #include <config.h>
@@ -21,6 +21,7 @@
 #include <stdlib.h>
 #include <stdio.h>
 #include <ctype.h>
+#include <stdbool.h>
 #ifdef HAVE_STRING_H
 #  include <string.h>
 #elif HAVE_STRINGS_H
@@ -32,7 +33,7 @@
 #include "errexit.e"
 
 EXPORT typedef enum {				/* Pseudo-classes */
-  Root, NthChild, NthOfType, FirstChild, FirstOfType, Lang
+  RootSel, NthChild, NthOfType, FirstChild, FirstOfType, Lang
 } PseudoType;
 
 EXPORT typedef struct _PseudoCond {
@@ -109,7 +110,7 @@ static string pseudos_to_string(const PseudoCond *p)
   sprintf(t1, "%d", p->a);
   sprintf(t2, "%d", p->b);
   switch (p->type) {
-  case Root:
+  case RootSel:
     strapp(&s, ":root", NULL); break;
   case NthChild:
     strapp(&s, ":nth-child(", t1, "n+", t2, ")", NULL); break;
@@ -212,7 +213,7 @@ static void push_sel(Selector *selector, Combinator combinator)
 }
 
 /* isnmstart -- check if a character can start an identifier */
-static Boolean isnmstart(unsigned int c)
+static bool isnmstart(unsigned int c)
 {
   return ('a' <= c && c <= 'z')
     || ('A' <= c && c <= 'Z')
@@ -221,7 +222,7 @@ static Boolean isnmstart(unsigned int c)
 }
 
 /* isnmchar -- check if a character can be inside an identifier */
-static Boolean isnmchar(unsigned int c)
+static bool isnmchar(unsigned int c)
 {
   return ('a' <= c && c <= 'z')
     || ('A' <= c && c <= 'Z')
@@ -415,7 +416,7 @@ EXPORT Selector parse_selector(const string selector)
       else errexit("Unknown pseudo-class \":ro%c...\"\n", *s);
       break;
     case PSEUDO_ROO:				/* After ':roo' */
-      if (*s == 't' || *s == 'T') {sel->pseudos->type = Root; s++; state=PSEUDO_ROOT;}
+      if (*s == 't' || *s == 'T') {sel->pseudos->type = RootSel; s++;state=PSEUDO_ROOT;}
       else errexit("Unknown pseudo-class \":roo%c...\"\n", *s);
       break;
     case PSEUDO_ROOT:				/* After ':root' */
