@@ -6,7 +6,7 @@
  *
  * Bert Bos
  * Created 10 May 1998
- * $Id: textwrap.c,v 1.24 2012/05/03 08:25:45 bbos Exp $
+ * $Id: textwrap.c,v 1.26 2013-03-23 23:18:10 bbos Exp $
  */
 #include <config.h>
 #include <stdio.h>
@@ -21,6 +21,7 @@
 # endif
 #endif
 #include <stdlib.h>
+#include <stdbool.h>
 #include "export.h"
 #include "types.e"
 #include "errexit.e"
@@ -68,9 +69,12 @@ EXPORT void flush()
     assert(len >= 0);
     assert(i <= len);
     i++;					/* Skip the breakpoint */
-    memmove(buf + level * indent, buf + i, len - i);
-    for (j = 0; j < level * indent; j++) buf[j] = NBSP; /* Indent */
-    len += level * indent - i;
+    len -= i;
+    if (len != 0) {		/* If anything left, insert the indent */
+      memmove(buf + level * indent, buf + i, len);
+      for (j = 0; j < level * indent; j++) buf[j] = NBSP; /* Indent */
+      len += level * indent;
+    }
   }
   /* Print rest, if any (removing non-break-space markers) */
   /* First remove spaces at end of line */
@@ -81,7 +85,7 @@ EXPORT void flush()
 }
 
 /* outc -- add one character to output buffer */
-EXPORT void outc(char c, Boolean preformatted)
+EXPORT void outc(char c, bool preformatted)
 {
   if (c == '\n' && !preformatted) c = ' ';	/* Newline is just a space */
   if (c == '\r' && !preformatted) c = ' ';	/* CR is just a space */
@@ -101,20 +105,20 @@ EXPORT void outc(char c, Boolean preformatted)
 }
 
 /* out -- add text to current output line, print line if getting too long */
-EXPORT void out(string s, Boolean preformatted)
+EXPORT void out(string s, bool preformatted)
 {
   if (s) for (; *s; s++) outc(*s, preformatted);
 }
 
 /* outn -- add n chars to current output, print line if getting too long */
-EXPORT void outn(string s, size_t n, Boolean preformatted)
+EXPORT void outn(string s, size_t n, bool preformatted)
 {
   size_t i;
   for (i = 0; i < n; i++) outc(s[i], preformatted);
 }
 
 /* outln -- add string to output buffer, followed by '\n' */
-EXPORT void outln(char *s, Boolean preformatted)
+EXPORT void outln(char *s, bool preformatted)
 {
   out(s, preformatted);
   flush();
