@@ -21,10 +21,12 @@
 #endif
 #include <ctype.h>
 #include <stdio.h>
+#include <stdbool.h>
 #include "export.h"
 #include "heap.e"
 #include "types.e"
 #include "dtd.e"
+#include "errexit.e"
 
 EXPORT typedef enum {
   Element, Text, Comment, Declaration, Procins, Root
@@ -106,7 +108,7 @@ EXPORT Tree get_root(Tree t)
 }
 
 
-/* get_attrib -- return a ptr to the value of a named attibute, or False */
+/* get_attrib -- return a ptr to the value of a named attibute, or false */
 EXPORT conststring get_attrib(const Node *e, const conststring attname)
 {
   assert(e->tp == Element);
@@ -121,8 +123,8 @@ EXPORT void set_attrib(Node *e, string name, conststring value)
   pairlist_set(&e->attribs, name, value);
 }
 
-/* delete_attrib -- remove attribute from element, False if not found */
-EXPORT Boolean delete_attrib(Node *e, const conststring name)
+/* delete_attrib -- remove attribute from element, false if not found */
+EXPORT bool delete_attrib(Node *e, const conststring name)
 {
   assert(e->tp == Element);
   return pairlist_unset(&e->attribs, name);
@@ -249,48 +251,48 @@ static const ElementType *lookup(const string e)
 }
 
 /* is_known -- true if the element is an HTML 4 element */
-EXPORT Boolean is_known(const string e)
+EXPORT bool is_known(const string e)
 {
   return lookup(e) != NULL;
 }
 
 /* is_pre -- true if the element has preformatted content */
-EXPORT Boolean is_pre(const string e)
+EXPORT bool is_pre(const string e)
 {
   const ElementType *info = lookup(e);
   return info && info->pre;
 }
 
 /* need_stag -- true if the element's start tag is required */
-EXPORT Boolean need_stag(const string e)
+EXPORT bool need_stag(const string e)
 {
   const ElementType *info = lookup(e);
   return !info || info->stag;
 }
 
 /* need_etag -- true if the element's end tag is required */
-EXPORT Boolean need_etag(const string e)
+EXPORT bool need_etag(const string e)
 {
   const ElementType *info = lookup(e);
   return !info || info->etag;
 }
 
 /* is_empty -- true if element is empty */
-EXPORT Boolean is_empty(const string e)
+EXPORT bool is_empty(const string e)
 {
   const ElementType *info = lookup(e);
   return info && info->empty;
 }
 
 /* has_parent -- true if c accepts p as a parent */
-EXPORT Boolean has_parent(const string c, const string p)
+EXPORT bool has_parent(const string c, const string p)
 {
   const ElementType *info = lookup_element(c, strlen(c));
   int i;
-  if (!info) return False;
+  if (!info) return false;
   for (i = 0; info->parents[i]; i++)
-    if (eq(info->parents[i], p)) return True;
-  return False;
+    if (eq(info->parents[i], p)) return true;
+  return false;
 }
 
 /* preferred_parent -- return first possible parent of e */
@@ -303,7 +305,7 @@ static string preferred_parent(const string e)
 }
   
 /* is_root -- true if e has no possible parents */
-static Boolean is_root(const string e)
+static bool is_root(const string e)
 {
   const ElementType *info = lookup_element(e, strlen(e));
   assert(info != NULL);				/* element is known */
@@ -311,28 +313,28 @@ static Boolean is_root(const string e)
 }
   
 /* is_mixed -- true if e accepts text content */
-EXPORT Boolean is_mixed(const string e)
+EXPORT bool is_mixed(const string e)
 {
   const ElementType *info = lookup(e);
   return !info || info->mixed;
 }
   
 /* break_before -- true if element looks better with a newline before it */
-EXPORT Boolean break_before(const string e)
+EXPORT bool break_before(const string e)
 {
   const ElementType *info = lookup(e);
   return info && info->break_before;
 }
   
 /* break_after -- true if element looks better with a newline after it */
-EXPORT Boolean break_after(const string e)
+EXPORT bool break_after(const string e)
 {
   const ElementType *info = lookup(e);
   return info && info->break_after;
 }
 
 /* build_path -- try to add omittable start tags to make elem acceptable */
-static Boolean build_path(Tree *t, string elem)
+static bool build_path(Tree *t, string elem)
 {
   const ElementType *info;
   Node *n;
@@ -342,13 +344,13 @@ static Boolean build_path(Tree *t, string elem)
   assert(is_known((*t)->name));
 
   /* Check if we are done */
-  if (has_parent(elem, (*t)->name)) return True;
+  if (has_parent(elem, (*t)->name)) return true;
   
   /* Try recursively if any possible parent can be a child of t */
   info = lookup(elem);
   for (i = 0; info->parents[i]; i++) {
     if (!need_stag(info->parents[i]) && build_path(t, info->parents[i])) {
-      /* Success, so add this parent and return True */
+      /* Success, so add this parent and return true */
       n = malloc(sizeof(*n));
       assert(n != NULL);
       n->tp = Element;
@@ -357,10 +359,22 @@ static Boolean build_path(Tree *t, string elem)
       n->attribs = NULL;
       n->sister = n->children = NULL;
       *t = push(*t, n);
-      return True;
+      return true;
     }
   }
-  return False;
+  return false;
+}
+
+/* tree_push -- add an element to the tree, without checking the DTD */
+EXPORT Tree tree_push(Tree t, string elem, pairlist attr)
+{
+  Node *n;
+  new(n);
+  n->tp = Element;
+  n->name = newstring(elem);
+  n->attribs = attr;
+  n->sister = n->children = NULL;
+  return push(t, n);
 }
 
 /* html_push -- add an element to the tree, open or close missing elements */
@@ -398,6 +412,18 @@ EXPORT Tree html_push(Tree t, string elem, pairlist attr)
   return t;
 }
 
+/* tree_pop -- close an open element, without checking the DTD */
+EXPORT Tree tree_pop(Tree t, string elem)
+{
+  assert(t != NULL);
+  if (t->tp == Root) errexit("End tag </%s> without matching start tag\n", elem);
+  assert(t->tp == Element);
+  if (*elem == '\0') return pop(t); /* Empty end tag </> */
+  if (eq(t->name, elem)) return pop(t);
+  errexit("End tag </%s> doesn't match start tag <%s>\n", elem, t->name);
+  return NULL;			/* Keep lint happy */
+}
+
 /* html_pop -- close an open element */
 EXPORT Tree html_pop(Tree t, string elem)
 {
@@ -452,6 +478,19 @@ EXPORT Tree append_procins(Tree t, string procins)
   return append(t, n);
 }
 
+/* tree_append_text -- append a text chunk, without checking the DTD */
+EXPORT Tree tree_append_text(Tree t, string text)
+{
+  Node *n;
+
+  assert(text);
+  new(n);
+  n->tp = Text;
+  n->text = text;
+  n->sister = n->children = NULL;
+  return append(t, n);
+}
+
 /* append_text -- append a text chunk to the document tree */
 EXPORT Tree append_text(Tree t, string text)
 {
